# FILE: oc.tcl
#
#	OOMMF core
#
# Last modified on: $Date: 2000/11/01 18:38:32 $
# Last modified by: $Author: dgp $
#
# When this version of the Oc extension is selected by the 'package require'
# command, this file is sourced.

# Verify minimum Tcl/Tk support
if {[catch {package require Tcl 8}]} {
    package require Tcl 7.5
}

proc Oc_CheckTclIndex {pkg} {
    if {[llength [info commands Oc_DirectPathname]]} {
        # Cosmetic fix, if it's available
        set index [Oc_DirectPathname \
            [file join [file dirname [info script]] tclIndex]]
    } else {
        set index [file join [file dirname [info script]] tclIndex]
    }
    if {![file isfile $index] || ![file readable $index]} {
        set msg "\nNo index found for $pkg\n\tMissing or unreadable\
                file: $index\n\n"
        if {[file exists [file join [file dirname [info script]] \
                makerules.tcl]]} {
            append msg "Run pimake in [file dirname $index]\nto construct\
                    the missing index file.\n"
        } else {
            append msg "This probably means $pkg was installed incorrectly.\n"
        }
        return -code error $msg
    }
}

if {[catch {Oc_CheckTclIndex Oc}]} {
    catch {auto_mkindex}
    if {[llength [info commands auto_mkindex_old]]} {
	interp alias {} auto_mkindex {} auto_mkindex_old
    }
    source [file join [file dirname [info script]] procs.tcl]
    Oc_MakeTclIndex [file dirname [info script]]
    Oc_CheckTclIndex Oc
}

# CVS 
package provide Oc 1.2.0.0

# Set up for autoloading of Oc extension commands
set oc(library) [file dirname [info script]]
if { [lsearch -exact $auto_path $oc(library)] == -1 } {
    lappend auto_path $oc(library)
}

# Gain access to other extensions in the OOMMF project
if { [lsearch -exact $auto_path [file dirname $oc(library)]] == -1 } {
    lappend auto_path [file dirname $oc(library)]
}

# Patch any bugs and missing features in old versions of Tcl
regsub {[.]} [package provide Tcl] {} _
set _ [file join [file dirname [info script]] bug$_.tcl]
if {[file readable $_]} {
    source $_
} else {
    source [file join [file dirname [info script]] bug.tcl]
}

# Bring in OOMMF customizations
source [file join [file dirname [info script]] custom.tcl]

# Initialize the Oc_Main class
Oc_Main Initialize

# If the C part of Oc is active, it provided [Oc_InitScript]
if {[llength [info commands Oc_InitScript]]} {
    # Add the command line options already parsed by the C part of Oc
    Oc_CommandLine Option tk {{flag {expr {![catch {expr {$flag && $flag}}]}} 
	"= 0 or 1"}} {#} "Enable or disable Tk (Some apps require Tk)"

    # If we also have Tk, add the options which Tk accepts
    if {[string length [package provide Tk]]} {
	Oc_CommandLine Option colormap window {#} \
		"Specify \"new\" to use private colormap (Tk)"
	Oc_CommandLine Option display display {#} "Display to use (Tk)"
	Oc_CommandLine Option geometry geometry {#} \
		"Initial geometry for window (Tk)"
	Oc_CommandLine Option name name {#} "Name to use for application (Tk)"
	Oc_CommandLine Option sync {} {#} "Use synchronous display mode (Tk)"
	Oc_CommandLine Option visual visual {#} "Visual for main window (Tk)"
	Oc_CommandLine Option use {{id {} "is ID of window to embed in"}} {#} \
		"Embed application in window (Tk)"
    }
}

Oc_CommandLine Option console {} [format {
    set file {%s}
    if {[file readable $file]} {
	if {[catch {uplevel #0 [list source $file]} msg]} {
	    return -code error "Can't create console: $msg"
	}
    } else {
	return -code error "Can't create console: File not readable: $file"
    }
} [file join [file dirname [info script]] console.tcl] ] \
"Display console window (requires Tk)"

Oc_CommandLine Option cwd {{directory {file isdirectory $directory} {}}} {
    cd $directory
} "Change working directory"

# Load in any local modifications
set _ [file join [file dirname [info script]] local oc.tcl]
if {[file isfile $_] && [file readable $_]} {
    uplevel #0 [list source $_]
}
unset _

